--[[
Atlasloot Enhanced
Author Daviesh
Loot browser associating loot with instance bosses
Can be integrated with Atlas (http://www.atlasmod.com)

Functions:
AtlasLoot_InitVariables()
AtlasLoot_OnEvent(event)
AtlasLoot_Atlas_OnShow()
AtlasLoot_ShowMenu()
AtlasLoot_OnVariablesLoaded()
AtlasLoot_SlashCommand(msg)
AtlasLootOptions_Toggle()
AtlasLoot_OnLoad()
AtlasLoot_Refresh()
AtlasLootBoss_OnClick()
AtlasLoot_ShowItemsFrame()
AtlasLoot_ShowBossLoot()
AtlasLoot_SetupForAtlas()
AtlasLoot_SetItemInfoFrame()
AtlasLootItemsFrame_OnCloseButton()
AtlasLoot_AtlasScrollBar_Update()
AtlasLootMenuItem_OnClick()
AtlasLoot_NavButton_OnClick()
AtlasLoot_HeroicModeToggle()
]]

--Instance required libraries
local BabbleBoss = AceLibrary("Babble-Boss-2.2");
local AL = AceLibrary("AceLocale-2.2"):new("AtlasLoot");

--Establish version number and compatible version of Atlas
local VERSION_MAJOR = "3";
local VERSION_MINOR = "00";
local VERSION_BOSSES = "06";
ATLASLOOT_VERSION = "|cffFF8400AtlasLoot Enhanced v"..VERSION_MAJOR.."."..VERSION_MINOR.."."..VERSION_BOSSES.."|r";
ATLASLOOT_CURRENT_ATLAS = "1.9.1";

--Standard indent to line text up with Atlas text
ATLASLOOT_INDENT = "   ";

--Make the Dewdrop menu in the standalone loot browser accessible here
AtlasLoot_Dewdrop = AceLibrary("Dewdrop-2.0");
AtlasLoot_DewdropSubMenu = AceLibrary("Dewdrop-2.0");

--Variable to cap debug spam
ATLASLOOT_DEBUGSHOWN = false;

-- Colours stored for code readability
local GREY = "|cff999999";
local RED = "|cffff0000";
local WHITE = "|cffFFFFFF";
local GREEN = "|cff1eff00";
local PURPLE = "|cff9F3FFF";
local BLUE = "|cff0070dd";
local ORANGE = "|cffFF8400";

--Establish number of boss lines in the Atlas frame for scrolling
local ATLAS_LOOT_BOSS_LINES	= 25;

--Flag so that error messages do not spam
local ATLASLOOT_POPUPSHOWN = false;

--Set the default anchor for the loot frame to the Atlas frame
AtlasLoot_AnchorFrame = AtlasFrame;	

--Variables to hold hooked Atlas functions
local Hooked_Atlas_Refresh;
local Hooked_Atlas_OnShow;

-- Initialise saved variables
if(AtlasLootOptions == nil) then
    AtlasLootOptions = {};
end
if(AtlasLootOptions == nil) then
       AtlasLootOptions = {};
end
if(AtlasLootSavedTooltips == nil) then
    AtlasLootSavedTooltips = {};
end
if ( AtlasLootOptions["SafeLinks"] == nil ) then
    AtlasLootOptions["SafeLinks"] = true;
end
if ( AtlasLootOptions["AllLinks"] == nil ) then
    AtlasLootOptions["AllLinks"] = false;
end
if ( AtlasLootOptions["DefaultTT"] == nil ) then
    AtlasLootOptions["DefaultTT"] = true;
end
if ( AtlasLootOptions["LootlinkTT"] == nil ) then
    AtlasLootOptions["LootlinkTT"] = false;
end
if ( AtlasLootOptions["ItemSyncTT"] == nil ) then
    AtlasLootOptions["ItemSyncTT"] = false;
end
if ( AtlasLootOptions["EquipCompare"] == nil ) then
    AtlasLootOptions["EquipCompare"] = false;
end
if ( AtlasLootOptions["Opaque"] == nil ) then
    AtlasLootOptions["Opaque"] = false;
end
if ( AtlasLootOptions["ItemIDs"] == nil ) then
    AtlasLootOptions["ItemIDs"] = false;
end
if ( AtlasLootOptions["MinimapButton"] == nil ) then
    AtlasLootOptions["MinimapButton"] = true;
end
if ( AtlasLootOptions["MinimapButtonAngle"] == nil ) then
    AtlasLootOptions["MinimapButtonAngle"] = 341;
end
if ( AtlasLootOptions["HidePanel"] == nil ) then
    AtlasLootOptions["HidePanel"] = false;
end
if ( AtlasLootOptions["LastBoss"] == nil ) then
    AtlasLootOptions["LastBoss"] = "GruulsLairHighKingMaulgar";
end
if ( AtlasLootOptions["LastBossText"] == nil ) then
    AtlasLootOptions["LastBossText"] = BabbleBoss["High King Maulgar"];
end
AtlasLootOptions["HeroicMode"] = false;

-- Popup Box for first time users
StaticPopupDialogs["ATLASLOOT_SETUP"] = {
  text = AL["Welcome to Atlasloot Enhanced.  Please take a moment to set your preferences for tooltips and links in the chat window.\n\n  This options screen can be reached again at any later time by typing '/atlasloot'."],
  button1 = AL["Setup"],
  OnAccept = function()
      AtlasLootOptions_Toggle();
  end,
  timeout = 0,
  whileDead = 1,
  hideOnEscape = 1
};

--Popup Box for an old version of Atlas
StaticPopupDialogs["ATLASLOOT_OLD_ATLAS"] = {
  text = AL["It has been detected that your version of Atlas does not match the version that Atlasloot is tuned for ("]..ATLASLOOT_CURRENT_ATLAS..AL[").  Depending on changes, there may be the occasional error, so please visit http://www.atlasmod.com as soon as possible to update."],
  button1 = AL["OK"],
  OnAccept = function()
      DEFAULT_CHAT_FRAME:AddMessage(BLUE..AL["AtlasLoot"]..": "..RED..AL["Incompatible Atlas Detected"]);
  end,
  timeout = 0,
  whileDead = 1,
  hideOnEscape = 1
};

--[[
AtlasLoot_InitVariables:
Function implemented to solve problems with saved variables not initialising
properly at startup.  Invoked when the addon has finished loading to ensure
proper saved variable initialisation
]]
function AtlasLoot_InitVariables()
    if(AtlasLootOptions == nil) then
        AtlasLootOptions = {};
    end
    if(AtlasLootSavedTooltips == nil) then
        AtlasLootSavedTooltips = {};
    end
    if ( AtlasLootOptions["SafeLinks"] == nil ) then
        AtlasLootOptions["SafeLinks"] = true;
    end
    if ( AtlasLootOptions["AllLinks"] == nil ) then
        AtlasLootOptions["AllLinks"] = false;
    end
    if ( AtlasLootOptions["DefaultTT"] == nil ) then
        AtlasLootOptions["DefaultTT"] = true;
    end
    if ( AtlasLootOptions["LootlinkTT"] == nil ) then
        AtlasLootOptions["LootlinkTT"] = false;
    end
    if ( AtlasLootOptions["ItemSyncTT"] == nil ) then
        AtlasLootOptions["ItemSyncTT"] = false;
    end
    if ( AtlasLootOptions["EquipCompare"] == nil ) then
        AtlasLootOptions["EquipCompare"] = false;
    end
    if ( AtlasLootOptions["Opaque"] == nil ) then
        AtlasLootOptions["Opaque"] = false;
    end
    if ( AtlasLootOptions["ItemIDs"] == nil ) then
        AtlasLootOptions["ItemIDs"] = false;
    end
    if ( AtlasLootOptions["MinimapButton"] == nil ) then
        AtlasLootOptions["MinimapButton"] = true;
    end
    if ( AtlasLootOptions["MinimapButtonAngle"] == nil ) then
        AtlasLootOptions["MinimapButtonAngle"] = 341;
    end
    if ( AtlasLootOptions["HidePanel"] == nil ) then
        AtlasLootOptions["HidePanel"] = false;
    end
    if ( AtlasLootOptions["LastBoss"] == nil ) then
        AtlasLootOptions["LastBoss"] = "GruulsLairHighKingMaulgar";
    end
    if ( AtlasLootOptions["LastBossText"] == nil ) then
        AtlasLootOptions["LastBossText"] = BabbleBoss["High King Maulgar"];
    end
    AtlasLootOptions["HeroicMode"] = false;
end

--[[
AtlasLoot_OnEvent(event):
event - Name of the event, passed from the API
Invoked whenever a relevant event is detected by the engine.  The function then
decides what action to take depending on the event.
]]
function AtlasLoot_OnEvent(event)
    --Addons all loaded
    if(event == "VARIABLES_LOADED") then
        AtlasLoot_OnVariablesLoaded();
    --Taint errors
    elseif (event == "ADDON_ACTION_FORBIDDEN" and arg1 == "AtlasLoot") then
        if ATLASLOOT_DEBUGSHOWN == false then
            DEFAULT_CHAT_FRAME:AddMessage("Tainted addon: "..arg1);
            DEFAULT_CHAT_FRAME:AddMessage("Tainted function: "..arg2);
            ATLASLOOT_DEBUGSHOWN = true;
        end
    elseif (event == "ADDON_ACTION_BLOCKED"  and arg1 == "AtlasLoot") then
        if ATLASLOOT_DEBUGSHOWN == false then
            DEFAULT_CHAT_FRAME:AddMessage("Tainted addon: "..arg1);
            DEFAULT_CHAT_FRAME:AddMessage("Tainted function: "..arg2);
            ATLASLOOT_DEBUGSHOWN = true;
        end
    end
end

--[[
AtlasLoot_Atlas_OnShow:
Hooks Atlas_OnShow() to add extra setup routines that AtlasLoot needs for
integration purposes.
]]
function AtlasLoot_Atlas_OnShow()
    --We don't want Atlas and the Loot Browser open at the same time, so the Loot Browser is close
    if AtlasLootDefaultFrame then
        AtlasLootDefaultFrame:Hide();
        AtlasLoot_SetupForAtlas();
    end
    --Call the Atlas function
    Hooked_Atlas_OnShow();
    --If we were looking at a loot table earlier in the session, it is still
    --saved on the item frame, so restore it in Atlas
    if AtlasLootItemsFrame.activeBoss ~= nil then
        AtlasLootItemsFrame:Show();
    else
        --If no loot table is selected, set up icons next to boss names
        for i=1,ATLAS_CUR_LINES do
            if (getglobal("AtlasEntry"..i.."_Selected") and getglobal("AtlasEntry"..i.."_Selected"):IsVisible()) then
                getglobal("AtlasEntry"..i.."_Loot"):Show();
                getglobal("AtlasEntry"..i.."_Selected"):Hide();
            end
        end
    end
    --Consult the saved variable table to see whether to show the bottom panel
    if AtlasLootOptions["HidePanel"] == true then
        AtlasLootPanel:Hide();
    else
        AtlasLootPanel:Show();
    end 
end

--[[
AtlasLoot_ShowMenu:
Legacy function used in Cosmos integration to open the loot browser
]]
function AtlasLoot_ShowMenu()
    AtlasLootDefaultFrame:Show();
end

--[[
AtlasLoot_OnVariablesLoaded:
Invoked by the VARIABLES_LOADED event.  Now that we are sure all the assets
the addon needs are in place, we can properly set up the mod
]]
function AtlasLoot_OnVariablesLoaded()
    --Add the loot browser to the special frames tables to enable closing wih the ESC key
    tinsert(UISpecialFrames, "AtlasLootDefaultFrame");
    --Legacy code for those using the ultimately failed attempt at making Atlas load on demand
    if AtlasButton_LoadAtlas then
        AtlasButton_LoadAtlas();
    end
    --Make sure all saved variables are established
    AtlasLoot_InitVariables();
    --Hook the necessary Atlas functions
    Hooked_Atlas_Refresh = Atlas_Refresh;
    Atlas_Refresh = AtlasLoot_Refresh;
    Hooked_Atlas_OnShow = Atlas_OnShow;
    Atlas_OnShow = AtlasLoot_Atlas_OnShow;
    --Instead of hooking, replace the scrollbar driver function
    AtlasScrollBar_Update = AtlasLoot_AtlasScrollBar_Update;
    --Disable options that don't have the supporting mods
    if( not LootLink_SetTooltip and (AtlasLootOptions.LootlinkTT == true)) then
        AtlasLootOptions.LootlinkTT = false;
        AtlasLootOptions.DefaultTT = true;
    end
    if( not ItemSync and (AtlasLootOptions.ItemSyncTT == true)) then
        AtlasLootOptions.ItemSyncTT = false;
        AtlasLootOptions.DefaultTT = true;
    end
    if( not EquipCompare_RegisterTooltip and (AtlasLootOptions.EquipCompare == true)) then
        AtlasLootOptions.EquipCompare = false;
    end
    --If using Equipcompare, register AtlasLoot with the tooltip handler
    if((EquipCompare_RegisterTooltip) and (AtlasLootOptions["EquipCompare"] == true)) then
        EquipCompare_RegisterTooltip(AtlasLootTooltip);
    end
    --If using an opaque items frame, change the alpha value of the backing texture
    if (AtlasLootOptions.Opaque) then
        AtlasLootItemsFrame_Back:SetTexture(0, 0, 0, 1);
    else
        AtlasLootItemsFrame_Back:SetTexture(0, 0, 0, 0.65);
    end
    --If Atlas is installed, set up for Atlas
    if ( Hooked_Atlas_Refresh ) then
        AtlasLoot_SetupForAtlas();
        --If a first time user, set up options
        if( (AtlasLootVersion == nil) or (tonumber(AtlasLootVersion) < 20100)) then
            AtlasLootOptions["SafeLinks"] = true;
            AtlasLootOptions["AllLinks"] = false;
            AtlasLootVersion = VERSION_MAJOR..VERSION_MINOR..VERSION_BOSSES;
            StaticPopup_Show ("ATLASLOOT_SETUP");
        end
        --If not the expected Atlas version
        if( ATLAS_VERSION ~= ATLASLOOT_CURRENT_ATLAS ) then
            StaticPopup_Show ("ATLASLOOT_OLD_ATLAS");
        end
        AtlasLoot_Refresh();
    else
        --If we are not using Atlas, keep the items frame out of the way
        AtlasLootItemsFrame:Hide();
    end
    --Adds an AtlasLoot button to the Feature Frame in Cosmos
    if(EarthFeature_AddButton) then
        EarthFeature_AddButton(
            {
                id = string.sub(ATLASLOOT_VERSION, 11, 28);
                name = string.sub(ATLASLOOT_VERSION, 11, 28);
                subtext = string.sub(ATLASLOOT_VERSION, 30, 39);
                tooltip = "";
                icon = "Interface\\Icons\\INV_Box_01";
                callback = AtlasLoot_ShowMenu;
                test = nil;
            }
    );
    --Adds AtlasLoot to old style Cosmos installations
    elseif(Cosmos_RegisterButton) then
        Cosmos_RegisterButton(
            string.sub(ATLASLOOT_VERSION, 11, 28),
            string.sub(ATLASLOOT_VERSION, 11, 28),
            "",
            "Interface\\Icons\\INV_Box_01",
            AtlasLoot_ShowMenu
        );
    end
    --Set up the menu in the loot browser
    AtlasLoot_DewdropRegister();
    --Enable or disable AtlasLootFu based on seleced options
    if AtlasLootOptions["MinimapButton"] == false then
        AtlasLootFu:Hide();
    else
        AtlasLootFu:Show();
        if FuBar then
            if AtlasLootFu:IsMinimapAttached() then
                AtlasLootFu:ToggleMinimapAttached()
            end
        end
    end
    --Position relevant UI objects for loot browser and set up menu
    AtlasLootDefaultFrame_SelectedCategory:SetPoint("TOP", "AtlasLootDefaultFrame_Menu", "BOTTOM", 0, -4);
    AtlasLootDefaultFrame_SelectedTable:SetPoint("TOP", "AtlasLootDefaultFrame_SubMenu", "BOTTOM", 0, -4);
    AtlasLootDefaultFrame_SelectedCategory:SetText(AL["Choose Table ..."]);
    AtlasLootDefaultFrame_SelectedTable:SetText("");
    AtlasLootDefaultFrame_SelectedCategory:Show();  
    AtlasLootDefaultFrame_SelectedTable:Show();
    AtlasLootDefaultFrame_SubMenu:Disable();
end

--[[
AtlasLoot_SlashCommand(msg):
msg - Not used (at present)
If someone types /atlasloot, bring up the options box
]]
function AtlasLoot_SlashCommand(msg)
    AtlasLootDefaultFrame:Show();
end

--[[
AtlasLootOptions_Toggle:
Toggle on/off the options window
]]
function AtlasLootOptions_Toggle()
    if(AtlasLootOptionsFrame:IsVisible()) then
        --Hide the options frame if already shown
        AtlasLootOptionsFrame:Hide();
    else
        AtlasLootOptionsFrame:Show();
        --Workaround for a weird quirk where tooltip settings so not immediately take effect
        if(AtlasLootOptions["DefaultTT"] == true) then
            AtlasLootOptions_DefaultTTToggle();
        elseif(AtlasLootOptions["LootlinkTT"] == true) then
            AtlasLootOptions_LootlinkTTToggle();
        elseif(AtlasLootOptions["ItemSyncTT"] == true) then
            AtlasLootOptions_ItemSyncTTToggle();
        end
    end
end

--[[
AtlasLoot_OnLoad:
Performs inital setup of the mod and registers it for further setup when
the required resources are in place
]]
function AtlasLoot_OnLoad()
    this:RegisterEvent("VARIABLES_LOADED");
    this:RegisterEvent("ADDON_ACTION_FORBIDDEN");
    this:RegisterEvent("ADDON_ACTION_BLOCKED");
    --Enable the use of /al or /atlasloot to open the loot browser
    SLASH_ATLASLOOT1 = "/atlasloot";
    SLASH_ATLASLOOT2 = "/al";
    SlashCmdList["ATLASLOOT"] = function(msg)
        AtlasLoot_SlashCommand(msg);
    end
end

--[[
AtlasLoot_Refresh:
Replacement for Atlas_Refresh, required as the template for the boss buttons in Atlas is insufficient
Called whenever the state of Atlas changes
]]
function AtlasLoot_Refresh()
    --Reset which loot page is 'current'
    AtlasLootItemsFrame.activeBoss = nil;
    --Get map selection info from Atlas
    local zoneID = ATLAS_DROPDOWNS[AtlasOptions.AtlasType][AtlasOptions.AtlasZone];
    local data = AtlasMaps[AtlasOptions.AtlasType];
    local base = {};
    
    --Get boss name information
    for k,v in pairs(AtlasMaps[AtlasOptions.AtlasType][zoneID]) do
        base[k] = v;
    end
    
    --Display the newly selected texture
    AtlasMap:ClearAllPoints();
    AtlasMap:SetWidth(512);
    AtlasMap:SetHeight(512);
    AtlasMap:SetPoint("TOPLEFT", "AtlasFrame", "TOPLEFT", 18, -84);
    local builtIn = AtlasMap:SetTexture("Interface\\AddOns\\Atlas\\Images\\Maps\\"..zoneID);
    
    --If texture was not found in the core Atlas mod, check plugins
    if ( not builtIn ) then
        for k,v in pairs(ATLAS_PLUGINS) do
            if ( AtlasMap:SetTexture("Interface\\AddOns\\"..v.."\\Images\\"..zoneID) ) then
                break;
            end
        end
    end
    
    --Setup info panel above boss listing
    local tName = base.ZoneName;
    if ( AtlasOptions.AtlasAcronyms and base.Acronym ~= nil) then
        local _RED = "|cffcc6666";
        tName = tName.._RED.." ["..base.Acronym.."]";
    end
    AtlasText_ZoneName:SetText(tName);
    local tLoc = "";
    local tLR = "";
    local tPL = "";
    if ( base.Location ) then
        tLoc = ATLAS_STRING_LOCATION..": "..base.Location;
    end
    if ( base.LevelRange ) then
        tLR = ATLAS_STRING_LEVELRANGE..": "..base.LevelRange;
    end
    if ( base.PlayerLimit ) then
        tPL = ATLAS_STRING_PLAYERLIMIT..": "..base.PlayerLimit;
    end
    AtlasText_Location:SetText(tLoc);
    AtlasText_LevelRange:SetText(tLR);
    AtlasText_PlayerLimit:SetText(tPL);
    
    Atlastextbase = base;
    --Get the size of the Atlas text to append stuff to the bottom.  Looks for empty lines
    local i = 1;
    local j = 2;
    while ( (Atlastextbase[i] ~= nil and Atlastextbase[i]~="") or (Atlastextbase[j] ~= nil and Atlastextbase[j]~="")) do
        i = i + 1;
        j = i + 1;
    end
    --Allow AtlasLoot to append any extra 'boss' entries needed to a map
    if AtlasLoot_ExtraText[zoneID] ~= nil then
        --Workaround for Old Hillsbrad, we don't want the Trash Mobs stuck under the 'flavour' NPCS
        if zoneID == "CoTOldHillsbrad" then
            Atlastextbase[19] = GREY..ATLASLOOT_INDENT..AL["Trash Mobs"];
        else
            for k,v in ipairs(AtlasLoot_ExtraText[zoneID]) do
                j = i + 1;
                --If the line after the empty line is not empty itself, all text below this point is shuffled down to make room
                if Atlastextbase[i]~=nil and Atlastextbase[i]~="" then
                    Atlastextbase[j] = Atlastextbase[i];
                end
                Atlastextbase[i]=v;
                i = i + 1;
            end
        end
    end
    
    --Hide any Atlas objects lurking around that have now been replaced
    for i=1,ATLAS_CUR_LINES do
        if ( getglobal("AtlasEntry"..i) ) then
            getglobal("AtlasEntry"..i):Hide();
        end
    end
    
    ATLAS_DATA = Atlastextbase;
    ATLAS_SEARCH_METHOD = data.Search;
    --Deal with Atlas's search function
    if ( data.Search == nil ) then
        ATLAS_SEARCH_METHOD = nil;
    end
    
    if ( data.Search ~= false ) then
        AtlasSearchEditBox:Show();
        AtlasNoSearch:Hide();
    else
        AtlasSearchEditBox:Hide();
        AtlasNoSearch:Show();
        ATLAS_SEARCH_METHOD = nil;
    end

    --populate the scroll frame entries list, the update func will do the rest
    Atlas_Search("");
    AtlasSearchEditBox:SetText("");
    AtlasSearchEditBox:ClearFocus();
    
    --create and align any new entry buttons that we need
    for i=1,ATLAS_CUR_LINES do
        if (not getglobal("AtlasBossLine"..i)) then
            local f = CreateFrame("Button", "AtlasBossLine"..i, AtlasFrame, "AtlasLootBossLineTemplate");
            if i==1 then
                f:SetPoint("TOPLEFT", "AtlasScrollBar", "TOPLEFT", 16, -3);
            else
                f:SetPoint("TOPLEFT", "AtlasBossLine"..(i-1), "BOTTOMLEFT");
            end
        else
            getglobal("AtlasBossLine"..i.."_Loot"):Hide();
            getglobal("AtlasBossLine"..i.."_Selected"):Hide();
        end
    end
    
    --Hide the loot frame now that a pristine Atlas instance is created
    AtlasLootItemsFrame:Hide();
    --Make sure the scroll bar is correctly offset
    AtlasLoot_AtlasScrollBar_Update();
    
end

--[[
AtlasLootBoss_OnClick:
Invoked whenever a boss line in Atlas is clicked
Shows a loot page if one is associated with the button
]]
function AtlasLootBoss_OnClick(name)
    local zoneID = ATLAS_DROPDOWNS[AtlasOptions.AtlasType][AtlasOptions.AtlasZone];
    local id = this.idnum;
    
    --This has been invoked from Atlas, so we remove any claim external mods have on the loot table
    AtlasLootItemsFrame.externalBoss = nil;
    
    --Hide the AtlasQuest frame if present so that the AtlasLoot items frame is not stuck under it
    if (AtlasQuestInsideFrame) then
        HideUIPanel(AtlasQuestInsideFrame);
    end
    
    --If the loot table was already shown and boss clicked again, hide the loot table and fix boss list icons
    if getglobal(name.."_Selected"):IsVisible() then
        getglobal(name.."_Selected"):Hide();
        getglobal(name.."_Loot"):Show();
        AtlasLootItemsFrame:Hide();
        AtlasLootItemsFrame.activeBoss = nil;
    else
        --If an loot table is associated with the button, show it.  Note multiple tables need to be checked due to the database structure
        if (AtlasLootBossButtons[zoneID] ~= nil and AtlasLootBossButtons[zoneID][id] ~= nil and AtlasLootBossButtons[zoneID][id] ~= "") then
            getglobal(name.."_Selected"):Show();
            getglobal(name.."_Loot"):Hide();
            local _,_,boss = string.find(getglobal(name.."_Text"):GetText(), "|c%x%x%x%x%x%x%x%x%s*[%dX]*[%) ]*(.*[^%,])[%,]?$");
            AtlasLoot_ShowBossLoot(AtlasLootBossButtons[zoneID][id], boss, AtlasFrame);
            AtlasLootItemsFrame.activeBoss = id;
            AtlasLoot_AtlasScrollBar_Update();
        elseif (AtlasLootWBBossButtons[zoneID] ~= nil and AtlasLootWBBossButtons[zoneID][id] ~= nil and AtlasLootWBBossButtons[zoneID][id] ~= "") then
            getglobal(name.."_Selected"):Show();
            getglobal(name.."_Loot"):Hide();
            local _,_,boss = string.find(getglobal(name.."_Text"):GetText(), "|c%x%x%x%x%x%x%x%x%s*[%dX]*[%) ]*(.*[^%,])[%,]?$");
            AtlasLoot_ShowBossLoot(AtlasLootWBBossButtons[zoneID][id], boss, AtlasFrame);
            AtlasLootItemsFrame.activeBoss = id;
            AtlasLoot_AtlasScrollBar_Update();
        elseif (AtlasLootBattlegrounds[zoneID] ~= nil and AtlasLootBattlegrounds[zoneID][id] ~= nil and AtlasLootBattlegrounds[zoneID][id] ~= "") then
            getglobal(name.."_Selected"):Show();
            getglobal(name.."_Loot"):Hide();
            local _,_,boss = string.find(getglobal(name.."_Text"):GetText(), "|c%x%x%x%x%x%x%x%x%s*[%wX]*[%) ]*(.*[^%,])[%,]?$");
            AtlasLoot_ShowBossLoot(AtlasLootBattlegrounds[zoneID][id], boss, AtlasFrame);
            AtlasLootItemsFrame.activeBoss = id;
            AtlasLoot_AtlasScrollBar_Update();
        end
    end
end

--[[
AtlasLoot_ShowItemsFrame(dataID, dataSource, boss, pFrame):
dataID - Name of the loot table
dataSource - Table in the database where the loot table is stored
boss - Text string to use as a title for the loot page
pFrame - Data structure describing how and where to anchor the item frame (more details, see the function AtlasLoot_SetItemInfoFrame)
This fuction is not normally called directly, it is usually invoked by AtlasLoot_ShowBossLoot.
It is the workhorse of the mod and allows the loot tables to be displayed any way anywhere in any mod.
]]
function AtlasLoot_ShowItemsFrame(dataID, dataSource, boss, pFrame)
    --Set up local variables needed for GetItemInfo, etc
    local itemName, itemLink, itemQuality, itemLevel, itemType, itemSubType, itemCount, itemEquipLoc, itemTexture, itemColor;
    local iconFrame, nameFrame, extraFrame;
    local text, extra;
    
    --If the data source has not been passed, throw up a debugging statement
    if dataSource==nil then
        DEFAULT_CHAT_FRAME:AddMessage("No dataSource!");
    end
    
    --If the loot table name has not been passed, throw up a debugging statement 
    if dataID==nil then
        DEFAULT_CHAT_FRAME:AddMessage("No dataID!");
    end
    
    --Set up checks to see if we have a heroic loot table or not
    local HeroicCheck=string.sub(dataID, string.len(dataID)-5, string.len(dataID));
    local HeroicdataID=dataID.."HEROIC";
    local NonHeroicdataID=string.sub(dataID, 1, string.len(dataID)-6);
    
    --Get AtlasQuest out of the way
    if (AtlasQuestInsideFrame) then
        HideUIPanel(AtlasQuestInsideFrame);
    end
    
    --Hide the toggle to switch between heroic and normal loot tables, we will only show it if required
    AtlasLootItemsFrame_Heroic:Hide();
    
    --Change the dataID to be consistant with the Heroic Mode toggle
    if((AtlasLootOptions["HeroicMode"] == nil) or (AtlasLootOptions["HeroicMode"] == false)) then
        if(HeroicCheck == "HEROIC") then
            if dataSource[NonHeroicdataID] then
                dataID=NonHeroicdataID;
            end
        end
    elseif(AtlasLootOptions["HeroicMode"] == true) then
        if(HeroicCheck ~= "HEROIC") then
            if dataSource[HeroicdataID] then
                dataID=HeroicdataID;
            end
        end
    end
    
    --Hide the menu objects.  These are not required for a loot table
    for i = 1, 30, 1 do
        getglobal("AtlasLootMenuItem_"..i):Hide();
    end
    
    --Escape out of this function if creating a menu, this function only handles loot tables.
    --Inserting escapes in this way allows consistant calling of data whether it is a loot table or a menu.
    if(dataID=="AQ40SET") then
        AtlasLootAQ40SetMenu();
    elseif(dataID=="AQ20SET") then
        AtlasLootAQ20SetMenu();
    elseif(dataID=="PRE60SET") then
        AtlasLootPRE60SetMenu();
    elseif(dataID=="ZGSET") then
        AtlasLootZGSetMenu();
    elseif(dataID=="T6SET") then
        AtlasLootT6SetMenu();
    elseif(dataID=="T5SET") then
        AtlasLootT5SetMenu();
    elseif(dataID=="T4SET") then
        AtlasLootT4SetMenu();
    elseif(dataID=="T3SET") then
        AtlasLootT3SetMenu();
    elseif(dataID=="T2SET") then
        AtlasLootT2SetMenu();
    elseif(dataID=="T1SET") then
        AtlasLootT1SetMenu();
    elseif(dataID=="T0SET") then
        AtlasLootT0SetMenu();
    elseif(dataID=="PVPSET") then
        AtlasLootPVPSetMenu();
    elseif(dataID=="PVP70SET") then
        AtlasLootPVP70SetMenu();
    elseif(dataID=="ARENASET") then
        AtlasLootARENASetMenu();
    elseif(dataID=="ARENA2SET") then
        AtlasLootARENA2SetMenu();
    elseif(dataID=="DS3SET") then
        AtlasLootDS3SetMenu();
    elseif(dataID=="CRAFTSET") then
        AtlasLootCraftedSetMenu();
    elseif(dataID=="CRAFTSET2") then
        AtlasLootCraftedSetMenu2();
    elseif(dataID=="REPMENU_ORIGINAL") then
        AtlasLootRepMenu_OriginalWoW();
    elseif(dataID=="REPMENU_BC") then
        AtlasLootRepMenu_BurningCrusade();
    elseif(dataID=="REPMENU") then
        AtlasLootRepMenu();
    else
        --Iterate through each item object and set its properties
        for i = 1, 30, 1 do
            --Check for a valid object (that it exists, and that it has a name)
            if(dataSource[dataID][i] ~= nil and dataSource[dataID][i][3] ~= "") then
                itemName, itemLink, itemQuality, itemLevel, itemMinLevel, itemType, itemSubType, itemCount, itemEquipLoc, itemTexture = GetItemInfo(dataSource[dataID][i][1]);
                --If the client has the name of the item in cache, use that instead.
                --This is poor man's localisation, English is replaced be whatever is needed
                if(GetItemInfo(dataSource[dataID][i][1])) then
                    _, _, _, itemColor = GetItemQualityColor(itemQuality);
                    text = itemColor..itemName;
                else
                    --If the item is not in cache, use the saved value and process it
                    text = dataSource[dataID][i][3];
                    text = AtlasLoot_FixText(text);
                end
                
                --Store data about the state of the items frame to allow minor tweaks or a recall of the current loot page
                AtlasLootItemsFrame.refresh = {dataID, dataSource, boss, pFrame};
                
                --Insert the item description
                extra = dataSource[dataID][i][4];
                extra = AtlasLoot_FixText(extra);
                --If the item is not in cache, querying the server may cause a disconnect
                --Show a red box around the item to indicate this to the user
                if((not GetItemInfo(dataSource[dataID][i][1])) and (dataSource[dataID][i][1] ~= 0)) then
                    getglobal("AtlasLootItem_"..i.."_Unsafe"):Show();
                    getglobal("AtlasLootItem_"..i).invalid = true;
                else
                    getglobal("AtlasLootItem_"..i.."_Unsafe"):Hide();
                    getglobal("AtlasLootItem_"..i).invalid = false;
                end
        
                --Use shortcuts for easier reference to parts of the item button
                iconFrame  = getglobal("AtlasLootItem_"..i.."_Icon");
                nameFrame  = getglobal("AtlasLootItem_"..i.."_Name");
                extraFrame = getglobal("AtlasLootItem_"..i.."_Extra");
                pricetext1 = getglobal("AtlasLootItem_"..i.."_PriceText1");
                pricetext2 = getglobal("AtlasLootItem_"..i.."_PriceText2");
                pricetext3 = getglobal("AtlasLootItem_"..i.."_PriceText3");
                pricetext4 = getglobal("AtlasLootItem_"..i.."_PriceText4");
                pricetext5 = getglobal("AtlasLootItem_"..i.."_PriceText5");
                priceicon1 = getglobal("AtlasLootItem_"..i.."_PriceIcon1");
                priceicon2 = getglobal("AtlasLootItem_"..i.."_PriceIcon2");
                priceicon3 = getglobal("AtlasLootItem_"..i.."_PriceIcon3");
                priceicon4 = getglobal("AtlasLootItem_"..i.."_PriceIcon4");
                priceicon5 = getglobal("AtlasLootItem_"..i.."_PriceIcon5");
            
                --If there is no data on the texture an item should have, show a big red question mark
                if dataSource[dataID][i][2] == "?" then
                    iconFrame:SetTexture("Interface\\Icons\\INV_Misc_QuestionMark");
                else
                    --else show the texture
                    iconFrame:SetTexture("Interface\\Icons\\"..dataSource[dataID][i][2]);
                    if iconFrame:GetTexture() == nil then
                        iconFrame:SetTexture("Interface\\Icons\\INV_Misc_QuestionMark");
                    end
                end
                --Set the name and description of the item
                nameFrame:SetText(text);
                extraFrame:SetText(extra);
                extraFrame:Show();
                
                --Hide the price UI objects, we only want the ones we are using to be visible
                pricetext1:Hide();
                pricetext2:Hide();
                pricetext3:Hide();
                pricetext4:Hide();
                pricetext5:Hide();
                priceicon1:Hide();
                priceicon2:Hide();
                priceicon3:Hide();
                priceicon4:Hide();
                priceicon5:Hide();
                
                --Set prices for items, up to 5 different currencies can be used in combination                
                if dataSource[dataID][i][6] then
                    if dataSource[dataID][i][6]~="" then
                        pricetext1:SetText(dataSource[dataID][i][6]);
                        priceicon1:SetTexture(AtlasLoot_FixText(dataSource[dataID][i][7]));
                        extraFrame:Hide();
                        pricetext1:Show();
                        priceicon1:Show();
                    end
                end
                
                if dataSource[dataID][i][8] then
                    if dataSource[dataID][i][8]~="" then
                        pricetext2:SetText(dataSource[dataID][i][8]);
                        priceicon2:SetTexture(AtlasLoot_FixText(dataSource[dataID][i][9]));
                        extraFrame:Hide();
                        pricetext2:Show();
                        priceicon2:Show();
                    end
                end
                
                if dataSource[dataID][i][10] then
                    if dataSource[dataID][i][10]~="" then
                        pricetext3:SetText(dataSource[dataID][i][10]);
                        priceicon3:SetTexture(AtlasLoot_FixText(dataSource[dataID][i][11]));
                        extraFrame:Hide();
                        pricetext3:Show();
                        priceicon3:Show();
                    end
                end
                
                if dataSource[dataID][i][12] then
                    if dataSource[dataID][i][12]~="" then
                        pricetext4:SetText(dataSource[dataID][i][12]);
                        priceicon4:SetTexture(AtlasLoot_FixText(dataSource[dataID][i][13]));
                        extraFrame:Hide();
                        pricetext4:Show();
                        priceicon4:Show();
                    end
                end
                
                if dataSource[dataID][i][14] then
                    if dataSource[dataID][i][14]~="" then
                        pricetext5:SetText(dataSource[dataID][i][14]);
                        priceicon5:SetTexture(AtlasLoot_FixText(dataSource[dataID][i][15]));
                        extraFrame:Hide();
                        pricetext5:Show();
                        priceicon5:Show();
                    end
                end
                
                --For convenience, we store information about the objects in the objects so that it can be easily accessed later                
                getglobal("AtlasLootItem_"..i).itemID = dataSource[dataID][i][1];
                getglobal("AtlasLootItem_"..i).storeID = dataSource[dataID][i][1];
                getglobal("AtlasLootItem_"..i).iteminfo = {};
                getglobal("AtlasLootItem_"..i).iteminfo.idcore = dataSource[dataID][i][1];
                getglobal("AtlasLootItem_"..i).iteminfo.icontexture = "Interface\\Icons\\"..dataSource[dataID][i][2];
                getglobal("AtlasLootItem_"..i).droprate = dataSource[dataID][i][5];
                if getglobal("AtlasLootItem_"..i).droprate == "" then
                    getglobal("AtlasLootItem_"..i).droprate = nil;
                end
                getglobal("AtlasLootItem_"..i).i = 1;
                getglobal("AtlasLootItem_"..i):Show();
                
                --Decide whether to show the Heroic mode toggle
                --Checks if a heroic version of the loot table is available.
                HeroicCheck=string.sub(dataID, string.len(dataID)-5, string.len(dataID));
                HeroicdataID=dataID.."HEROIC";
                if dataSource[HeroicdataID] then
                    AtlasLootItemsFrame_Heroic:Show();
                    AtlasLootItemsFrame_Heroic:SetChecked(false);
                else
                    if HeroicCheck=="HEROIC" then
                        AtlasLootItemsFrame_Heroic:Show();
                        AtlasLootItemsFrame_Heroic:SetChecked(true);
                    end
                end
            else
                getglobal("AtlasLootItem_"..i):Hide();
            end
        end
        
        --Hide navigation buttons by default, only show what we need
        getglobal("AtlasLootItemsFrame_BACK"):Hide();
        getglobal("AtlasLootItemsFrame_NEXT"):Hide();
        getglobal("AtlasLootItemsFrame_PREV"):Hide();
        AtlasLoot_BossName:SetText(boss);
        --Consult the button registry to determine what nav buttons are required
        if AtlasLoot_ButtonRegistry[dataID] then
            local tablebase = AtlasLoot_ButtonRegistry[dataID];
            AtlasLoot_BossName:SetText(tablebase.Title);
            if tablebase.Next_Page then
                getglobal("AtlasLootItemsFrame_NEXT"):Show();
                getglobal("AtlasLootItemsFrame_NEXT").lootpage = tablebase.Next_Page;
                getglobal("AtlasLootItemsFrame_NEXT").title = tablebase.Next_Title;
            end
            if tablebase.Prev_Page then
                getglobal("AtlasLootItemsFrame_PREV"):Show();
                getglobal("AtlasLootItemsFrame_PREV").lootpage = tablebase.Prev_Page;
                getglobal("AtlasLootItemsFrame_PREV").title = tablebase.Prev_Title;
            end
            if tablebase.Back_Page then
                getglobal("AtlasLootItemsFrame_BACK"):Show();
                getglobal("AtlasLootItemsFrame_BACK").lootpage = tablebase.Back_Page;
                getglobal("AtlasLootItemsFrame_BACK").title = tablebase.Back_Title;
            end
        end
    end
    
    --For Alphamap and Atlas integration, show a 'close' button to hide the loot table and restore the map view
    if (AtlasLootItemsFrame:GetParent() == AlphaMapAlphaMapFrame or AtlasLootItemsFrame:GetParent() == AtlasFrame) then
        AtlasLootItemsFrame_CloseButton:Show();
    else
        AtlasLootItemsFrame_CloseButton:Hide();
    end

    --Anchor the item frame where it is supposed to be    
    AtlasLoot_SetItemInfoFrame(pFrame);	
end

--[[
AtlasLoot_ShowBossLoot(dataID, boss, pFrame):
dataID - Name of the loot table
boss - Text string to be used as the title for the loot page
pFrame - Data structure describing how and where to anchor the item frame (more details, see the function AtlasLoot_SetItemInfoFrame)
This is the intended API for external mods to use for displaying loot pages.
This function figures out where the loot table is stored, then sends the relevant info to AtlasLoot_ShowItemsFrame
]]
function AtlasLoot_ShowBossLoot(dataID, boss, pFrame)

    AtlasLootItemsFrame:Hide();

    --If the loot table is already being displayed, it is hidden and the current table selection cancelled
    if ( dataID == AtlasLootItemsFrame.externalBoss ) and (AtlasLootItemsFrame:GetParent() ~= AtlasFrame) and (AtlasLootItemsFrame:GetParent() ~= AtlasLootDefaultFrame_LootBackground) then
        AtlasLootItemsFrame.externalBoss = nil;
    else
        --Use the original WoW instance data by default
        local dataSource = AtlasLootItems;
        --Check if the loot table is in a different part of the database
        --The assumption is made that loot table names are unique through the DB
        if ( AtlasLootBGItems[dataID] ) then	
            dataSource = AtlasLootBGItems;
        elseif ( AtlasLootWBItems[dataID] ) then    
            dataSource = AtlasLootWBItems;
        elseif ( AtlasLootSetItems[dataID] ) then    
            dataSource = AtlasLootSetItems;
        elseif ( AtlasLootWorldPvPItems[dataID] ) then 
            dataSource = AtlasLootWorldPvPItems;
        elseif ( AtlasLootGeneralPvPItems[dataID] ) then    
            dataSource = AtlasLootGeneralPvPItems;
        elseif ( AtlasLootRepItems[dataID] ) then   
            dataSource = AtlasLootRepItems;
        elseif ( AtlasLootExpansionItems[dataID] ) then 
            dataSource = AtlasLootExpansionItems;
        end

        --Set anchor point, set selected table and call AtlasLoot_ShowItemsFrame
        AtlasLoot_AnchorFrame = pFrame;
        AtlasLootItemsFrame.externalBoss = dataID;
        AtlasLoot_ShowItemsFrame(dataID, dataSource, boss, pFrame);
    end

end

--[[
AtlasLoot_SetupForAtlas:
This function sets up the Atlas specific XML objects
]]
function AtlasLoot_SetupForAtlas()
    --Poisition the frame with the AtlasLoot version details in the Atlas frame
    AtlasLootInfo:ClearAllPoints();
    AtlasLootInfo:SetParent(AtlasFrame);
    AtlasLootInfo:SetPoint("TOPLEFT", "AtlasFrame", "TOPLEFT", 546, -3);
    
    --Anchor the bottom panel to the Atlas frame
    AtlasLootPanel:ClearAllPoints();
    AtlasLootPanel:SetParent(AtlasFrame);
    AtlasLootPanel:SetPoint("TOP", "AtlasFrame", "BOTTOM", 0, 9);

    --Anchor the loot table to the Atlas frame
    AtlasLoot_SetItemInfoFrame();
    AtlasLootItemsFrame:Hide();
    AtlasLoot_AnchorFrame = AtlasFrame;	
end

--[[
AtlasLoot_SetItemInfoFrame(pFrame):
pFrame - Data structure with anchor info.  Format: {Anchor Point, Relative Frame, Relative Point, X Offset, Y Offset }
This function anchors the item frame where appropriate.  The main Atlas frame can be passed instead of a custom pFrame.
If no pFrame is specified, the Atlas Frame is used if Atlas is installed.
]]
function AtlasLoot_SetItemInfoFrame(pFrame)
    if ( pFrame ) then
        --If a pFrame is specified, use it
        if(pFrame==AtlasFrame and AtlasFrame) then
            AtlasLootItemsFrame:ClearAllPoints();
            AtlasLootItemsFrame:SetParent(AtlasFrame);
            AtlasLootItemsFrame:SetPoint("TOPLEFT", "AtlasFrame", "TOPLEFT", 18, -84);
        else
            AtlasLootItemsFrame:ClearAllPoints();
            AtlasLootItemsFrame:SetParent(pFrame[2]);
            AtlasLootItemsFrame:ClearAllPoints();
            AtlasLootItemsFrame:SetPoint(pFrame[1], pFrame[2], pFrame[3], pFrame[4], pFrame[5]);
        end
    elseif ( AtlasFrame ) then
        --If no pFrame is specified and Atlas is installed, anchor in Atlas
        AtlasLootItemsFrame:ClearAllPoints();
        AtlasLootItemsFrame:SetParent(AtlasFrame);
        AtlasLootItemsFrame:SetPoint("TOPLEFT", "AtlasFrame", "TOPLEFT", 18, -84);
    else
        --Last resort, dump the items frame in the middle of the screen
        AtlasLootItemsFrame:ClearAllPoints();
        AtlasLootItemsFrame:SetParent(UIParent);
        AtlasLootItemsFrame:SetPoint("CENTER", "UIParent", "CENTER", 0, 0);
    end
    AtlasLootItemsFrame:Show();
end

--[[
AtlasLootItemsFrame_OnCloseButton:
Called when the close button on the item frame is clicked
]]
function AtlasLootItemsFrame_OnCloseButton()
    --Set no loot table as currently selected
    AtlasLootItemsFrame.activeBoss = nil;
    --Fix the boss buttons so the correct icons are displayed
    if ATLAS_CUR_LINES then
        for i=1,ATLAS_CUR_LINES do
            if getglobal("AtlasBossLine"..i.."_Selected"):IsVisible() then
                getglobal("AtlasBossLine"..i.."_Selected"):Hide();
                getglobal("AtlasBossLine"..i.."_Loot"):Show();
            end
        end
    end
    --Hide the item frame    
    AtlasLootItemsFrame:Hide();
end

--[[
AtlasLoot_AtlasScrollBar_Update:
Hooks the Atlas scroll frame.  
Required as the Atlas function cannot deal with the AtlasLoot button template or the added Atlasloot entries
]]
function AtlasLoot_AtlasScrollBar_Update()
    local line, lineplusoffset;
    local zoneID = ATLAS_DROPDOWNS[AtlasOptions.AtlasType][AtlasOptions.AtlasZone];
    --Update the contents of the Atlas scroll frame
    FauxScrollFrame_Update(AtlasScrollBar,ATLAS_CUR_LINES,ATLAS_LOOT_BOSS_LINES,15);
    --Make note of how far in the scroll frame we are
    for line=1,ATLAS_NUM_LINES do
        lineplusoffset = line + FauxScrollFrame_GetOffset(AtlasScrollBar);
        if ( lineplusoffset <= ATLAS_CUR_LINES ) then
            getglobal("AtlasBossLine"..line.."_Text"):SetText(ATLAS_SCROLL_LIST[lineplusoffset]);
            if AtlasLootItemsFrame.activeBoss == lineplusoffset then
                getglobal("AtlasBossLine"..line.."_Loot"):Hide();
                getglobal("AtlasBossLine"..line.."_Selected"):Show();
            elseif (AtlasLootBossButtons[zoneID]~=nil and AtlasLootBossButtons[zoneID][lineplusoffset] ~= nil and AtlasLootBossButtons[zoneID][lineplusoffset] ~= "") then
                getglobal("AtlasBossLine"..line.."_Loot"):Show();
                getglobal("AtlasBossLine"..line.."_Selected"):Hide();
            elseif (AtlasLootWBBossButtons[zoneID]~=nil and AtlasLootWBBossButtons[zoneID][lineplusoffset] ~= nil and AtlasLootWBBossButtons[zoneID][lineplusoffset] ~= "") then
                getglobal("AtlasBossLine"..line.."_Loot"):Show();
                getglobal("AtlasBossLine"..line.."_Selected"):Hide();
            elseif (AtlasLootBattlegrounds[zoneID]~=nil and AtlasLootBattlegrounds[zoneID][lineplusoffset] ~= nil and AtlasLootBattlegrounds[zoneID][lineplusoffset] ~= "") then
                getglobal("AtlasBossLine"..line.."_Loot"):Show();
                getglobal("AtlasBossLine"..line.."_Selected"):Hide();
            else
                getglobal("AtlasBossLine"..line.."_Loot"):Hide();
                getglobal("AtlasBossLine"..line.."_Selected"):Hide();
            end
            getglobal("AtlasBossLine"..line).idnum = lineplusoffset;
            getglobal("AtlasBossLine"..line):Show();
        elseif ( getglobal("AtlasBossLine"..line) ) then
            --Hide lines that are not needed
            getglobal("AtlasBossLine"..line):Hide();
        end
    end
end

--[[
AtlasLootMenuItem_OnClick:
Requests the relevant loot page from a menu screen
]]
function AtlasLootMenuItem_OnClick()
    if this.isheader == nil or this.isheader == false then
        AtlasLoot_ShowBossLoot(this.lootpage, getglobal(this:GetName().."_Name"):GetText(), AtlasLoot_AnchorFrame);
    end
end

--[[
AtlasLoot_NavButton_OnClick:
Called when <-, -> or 'Back' are pressed and calls up the appropriate loot page
]]
function AtlasLoot_NavButton_OnClick()
    if AtlasLootItemsFrame.refresh and AtlasLootItemsFrame.refresh[2] and AtlasLootItemsFrame.refresh[4] then
        AtlasLoot_ShowItemsFrame(this.lootpage, AtlasLootItemsFrame.refresh[2], this.title, AtlasLootItemsFrame.refresh[4]);
    else
        --Fallback for if the requested loot page is a menu and does not have a .refresh instance
        AtlasLoot_ShowItemsFrame(this.lootpage, "dummy", this.title, AtlasFrame);
    end
end

--[[
AtlasLoot_HeroicModeToggle:
Switches between the heroic and normal versions of a loot page
]]
function AtlasLoot_HeroicModeToggle()
    local Heroic = AtlasLootItemsFrame.refresh[1].."HEROIC";
    local dataID = AtlasLootItemsFrame.refresh[1];
    local HeroicCheck=string.sub(dataID, string.len(dataID)-5, string.len(dataID));
    local Lootpage;
    if HeroicCheck=="HEROIC" then
        Lootpage=string.sub(dataID, 1, string.len(dataID)-6);
        AtlasLootOptions["HeroicMode"] = false;
    else
        Lootpage=Heroic;
        AtlasLootOptions["HeroicMode"] = true;
    end
    AtlasLoot_ShowItemsFrame(Lootpage, AtlasLootItemsFrame.refresh[2], AtlasLootItemsFrame.refresh[3], AtlasLootItemsFrame.refresh[4]);
end


                            
